@@ -192,7 +192,7 @@ weaveRhtml<-function(in.file,out.file,replace.umlaute=TRUE){
     #hh<-floor(as.numeric(hh)*35*l.unit)
     #hh<-ifelse(is.na(hh),"",paste(" height=",hh,sep=""))
     #h<-paste("<img SRC=\"",sub(".ps$",".jpg",h),"\"",hh,">",sep="")
-    h<-paste("<img SRC=\"",sub(".ps$",".jpg",h),"\">",sep="")
+    h<-paste("<img SRC=\"",sub("\\.[e]{,1}ps$","",h),".jpg","\">",sep="") #090227
     input[plz.ind]<-h
   }
 
@@ -201,7 +201,7 @@ weaveRhtml<-function(in.file,out.file,replace.umlaute=TRUE){
   code.lines<-input[code.index]
   ## print(input[code.start.index])
 
-  no<-1:length(code.start.index)
+  no<-seq(along=code.start.index)
   def.ref.no<-match(gsub("\\ ","",code.start.lines), gsub("\\ ","",code.start.lines))
   code.start.lines<-paste(
         "<a name=\"codechunk",no,"\"></a>",
@@ -215,7 +215,7 @@ weaveRhtml<-function(in.file,out.file,replace.umlaute=TRUE){
   use.lines<-substring(use.lines,nchar(leerzeichen.vor.use))
   h<-gsub("\\ ","&nbsp;",leerzeichen.vor.use)
   leerzeichen.vor.use<-ifelse(is.use.lines.within.code,h,leerzeichen.vor.use)
-  for(i in seq(use.lines)){
+  for(i in seq(along=use.lines)){
     uli<-use.lines[i]
     such<-paste("(.*)<","<(.*)>",">(.*)",sep="")
     repeat{
@@ -447,88 +447,108 @@ weaveRhtml<-function(in.file,out.file,replace.umlaute=TRUE){
 
   # find sections, subsections, subsubsections, paragraphs
   atag<-"<h2>"; etag<-"</h2>"; command<-"section"
-  command.n<-nchar(command)+2; command.links<-NULL
+  command.n<-nchar(command)+2; command.links<-NULL  
   kla<-"{"; kle<-"}"
   ## print("STRUKTUR")
   if(0<length(com.lines<-grep(paste("^\\\\",command,sep=""),input))){
     sec<-NULL
-    for(i in seq(com.lines)){
+    for(i in seq(along=com.lines)){
       txt<-input[com.lines[i]+0:2]
       txt<-paste(txt,collapse="\n"); n<-nchar(txt)   
-      x<-substring(txt,command.n:n,command.n:n)
-      en<-which(cumsum((x==kla)-(x==kle))==0)[1]
+      x<-sub("^ *","",substring(txt,command.n))
+      if((n.x<-nchar(x))<3){x<-paste(x,"no title?"); n.x<-nchar(x)}
+      x<-substring(x,1:n.x,1:n.x)
+      if(x[1]!=kla) {x[2] <-paste(x[1],x[2],sep=""); x[1]<-"{"} #}
+      en<-  which(cumsum((x==kla)-(x==kle))==0)[1] ## 090212??
+      if(is.na(en)) {en<-length(x); x[en]<-paste(x[en],etag)} else x[en]<-etag
       x[1]<-paste("<a name=\"",command,i,"\">",atag,sep="")
-      x[en]<-etag;  txt<-paste(x,collapse="")
-      sec<-c(sec,paste(x[2:(en-1)],collapse=""))
+      txt<-paste(x,collapse=""); sec<-c(sec,paste(x[(1+1):(en-1)],collapse=""))
       input[com.lines[i]+0:2]<-unlist(strsplit(txt,"\n"))
     }
-    command.links<-paste("<a href=\"#",command,seq(com.lines),
+    command.links<-paste("<a href=\"#",command,seq(along=com.lines),
                                         "\">",sec,"</a>\n",sep="") 
   }
-
+  #   if(is.na(an)) {an<-1; x[an]<-paste(x[an],etag)} else x[an]<-h
+  #   en<-which(cumsum((x=="{")-(x=="}"))==0)[1]
+      
   sec.links<-command.links; sec.no<-com.lines
   atag<-"<h3>"; etag<-"</h3>"; command<-"subsection"
-  command.n<-nchar(command)+2; command.links<-NULL
+  command.n<-nchar(command)+2; command.links<-NULL  
   kla<-"{"; kle<-"}"
   ## print("STRUKTUR")
   if(0<length(com.lines<-grep(paste("^\\\\",command,sep=""),input))){
     sec<-NULL
-    for(i in seq(com.lines)){
+    for(i in seq(along=com.lines)){
       txt<-input[com.lines[i]+0:2]
       txt<-paste(txt,collapse="\n"); n<-nchar(txt)   
-      x<-substring(txt,command.n:n,command.n:n)
-      en<-which(cumsum((x==kla)-(x==kle))==0)[1]
+      x<-sub("^ *","",substring(txt,command.n))
+      if((n.x<-nchar(x))<3){x<-paste(x,"no title?"); n.x<-nchar(x)}
+      x<-substring(x,1:n.x,1:n.x)
+      if(x[1]!=kla) {x[2] <-paste(x[1],x[2],sep=""); x[1]<-"{"} #}
+      en<-  which(cumsum((x==kla)-(x==kle))==0)[1] ## 090212??
+      if(is.na(en)) {en<-length(x); x[en]<-paste(x[en],etag)} else x[en]<-etag
       x[1]<-paste("<a name=\"",command,i,"\">",atag,sep="")
-      x[en]<-etag;  txt<-paste(x,collapse="")
-      sec<-c(sec,paste(x[2:(en-1)],collapse=""))
+      txt<-paste(x,collapse=""); sec<-c(sec,paste(x[(1+1):(en-1)],collapse=""))
       input[com.lines[i]+0:2]<-unlist(strsplit(txt,"\n"))
     }
-    command.links<-paste("<a href=\"#",command,seq(com.lines),
+    command.links<-paste("<a href=\"#",command,seq(along=com.lines),
                                         "\">",sec,"</a>\n",sep="") 
   }
-
+  #   if(is.na(an)) {an<-1; x[an]<-paste(x[an],etag)} else x[an]<-h
+  #   en<-which(cumsum((x=="{")-(x=="}"))==0)[1]
+      
   subsec.links<-command.links; subsec.no<-com.lines
   atag<-"<h4>"; etag<-"</h4>"; command<-"subsubsection"
-  command.n<-nchar(command)+2; command.links<-NULL
+  command.n<-nchar(command)+2; command.links<-NULL  
   kla<-"{"; kle<-"}"
   ## print("STRUKTUR")
   if(0<length(com.lines<-grep(paste("^\\\\",command,sep=""),input))){
     sec<-NULL
-    for(i in seq(com.lines)){
+    for(i in seq(along=com.lines)){
       txt<-input[com.lines[i]+0:2]
       txt<-paste(txt,collapse="\n"); n<-nchar(txt)   
-      x<-substring(txt,command.n:n,command.n:n)
-      en<-which(cumsum((x==kla)-(x==kle))==0)[1]
+      x<-sub("^ *","",substring(txt,command.n))
+      if((n.x<-nchar(x))<3){x<-paste(x,"no title?"); n.x<-nchar(x)}
+      x<-substring(x,1:n.x,1:n.x)
+      if(x[1]!=kla) {x[2] <-paste(x[1],x[2],sep=""); x[1]<-"{"} #}
+      en<-  which(cumsum((x==kla)-(x==kle))==0)[1] ## 090212??
+      if(is.na(en)) {en<-length(x); x[en]<-paste(x[en],etag)} else x[en]<-etag
       x[1]<-paste("<a name=\"",command,i,"\">",atag,sep="")
-      x[en]<-etag;  txt<-paste(x,collapse="")
-      sec<-c(sec,paste(x[2:(en-1)],collapse=""))
+      txt<-paste(x,collapse=""); sec<-c(sec,paste(x[(1+1):(en-1)],collapse=""))
       input[com.lines[i]+0:2]<-unlist(strsplit(txt,"\n"))
     }
-    command.links<-paste("<a href=\"#",command,seq(com.lines),
+    command.links<-paste("<a href=\"#",command,seq(along=com.lines),
                                         "\">",sec,"</a>\n",sep="") 
   }
-
+  #   if(is.na(an)) {an<-1; x[an]<-paste(x[an],etag)} else x[an]<-h
+  #   en<-which(cumsum((x=="{")-(x=="}"))==0)[1]
+      
   subsubsec.links<-command.links; subsubsec.no<-com.lines
   atag<-"<br><b>"; etag<-"</b>"; command<-"paragraph"
-  command.n<-nchar(command)+2; command.links<-NULL
+  command.n<-nchar(command)+2; command.links<-NULL  
   kla<-"{"; kle<-"}"
   ## print("STRUKTUR")
   if(0<length(com.lines<-grep(paste("^\\\\",command,sep=""),input))){
     sec<-NULL
-    for(i in seq(com.lines)){
+    for(i in seq(along=com.lines)){
       txt<-input[com.lines[i]+0:2]
       txt<-paste(txt,collapse="\n"); n<-nchar(txt)   
-      x<-substring(txt,command.n:n,command.n:n)
-      en<-which(cumsum((x==kla)-(x==kle))==0)[1]
+      x<-sub("^ *","",substring(txt,command.n))
+      if((n.x<-nchar(x))<3){x<-paste(x,"no title?"); n.x<-nchar(x)}
+      x<-substring(x,1:n.x,1:n.x)
+      if(x[1]!=kla) {x[2] <-paste(x[1],x[2],sep=""); x[1]<-"{"} #}
+      en<-  which(cumsum((x==kla)-(x==kle))==0)[1] ## 090212??
+      if(is.na(en)) {en<-length(x); x[en]<-paste(x[en],etag)} else x[en]<-etag
       x[1]<-paste("<a name=\"",command,i,"\">",atag,sep="")
-      x[en]<-etag;  txt<-paste(x,collapse="")
-      sec<-c(sec,paste(x[2:(en-1)],collapse=""))
+      txt<-paste(x,collapse=""); sec<-c(sec,paste(x[(1+1):(en-1)],collapse=""))
       input[com.lines[i]+0:2]<-unlist(strsplit(txt,"\n"))
     }
-    command.links<-paste("<a href=\"#",command,seq(com.lines),
+    command.links<-paste("<a href=\"#",command,seq(along=com.lines),
                                         "\">",sec,"</a>\n",sep="") 
   }
-
+  #   if(is.na(an)) {an<-1; x[an]<-paste(x[an],etag)} else x[an]<-h
+  #   en<-which(cumsum((x=="{")-(x=="}"))==0)[1]
+      
   parsec.links<-command.links; parsec.no<-com.lines
   sec.typ<-rbind(cbind(c(0,sec.no),1),cbind(c(0,subsec.no),2),
                           cbind(c(0,subsubsec.no),3),cbind(c(0,parsec.no),4))
@@ -578,7 +598,8 @@ weaveRhtml<-function(in.file,out.file,replace.umlaute=TRUE){
     if(is.null(datum)) datum<-date()
     ## print(datum)
   } else {
-    head<-""; titel<-paste("File:",in.file); autor<-"processed by weaveRhtml"; datum<-date()
+    head<-""; titel<-paste("File:",in.file); autor<-"processed by weaveRhtml"
+    datum<-date()
   }
   if(0<length(h<-grep("\\\\begin\\{document\\}",input)))
     input<-input[-(1:h[1])]
@@ -627,7 +648,8 @@ weaveRhtml<-function(in.file,out.file,replace.umlaute=TRUE){
       ## if( DEBUG-Flag gesetzt ) print(ind.Rweb.codes)
       Rwebbegin<-paste(c(  # Rweb start 
         '<hr SIZE=3><form onSubmit =" return checkData(this)"',
-        '  action="http://rweb.stat.umn.edu/cgi-bin/Rweb/Rweb.cgi" ',
+        ## '  action="http://rweb.stat.umn.edu/cgi-bin/Rweb/Rweb.cgi" ', ## out of order
+        '  action="http://pbil.univ-lyon1.fr/cgi-bin/Rweb/Rweb.cgi" ',
         '  enctype="multipart/form-data" method="post" target="_blank"><p>',
         '<label for="filedata" size=20>data frame (load LOCAL file): </label>',
         '<input type="file" name="FileData" id="filedata" size=30 >',
@@ -644,7 +666,7 @@ weaveRhtml<-function(in.file,out.file,replace.umlaute=TRUE){
         '<input type="reset" value="reset">',
         '</form><hr SIZE=3>',
         ' '),collapse=" ")
-      for(i in seq(ind.Rweb.codes)){
+      for(i in seq(along=ind.Rweb.codes)){
         h<-sub("<code>","",txt[ind.Rweb.codes[[i]]])
         h<-sub("<br>","",h)
         h<-sub("</code>","",h)
